<?php
/**
 * Copyright © 2016 Filoblu S.r.l. All rights reserved.
 */

namespace FiloBlu\Esb\Block\Adminhtml\System\Config;

/**
 * Renderer for Event Configuration
 */

class Events extends \Magento\Config\Block\System\Config\Form\Field\FieldArray\AbstractFieldArray
{
    
    /**
     * @var \Magento\Sales\Model\ResourceModel\Order\Status\Collection
     */
    protected $collection;

    /**
     * Statuses per state array
     *
     * @var array
     */
    protected $stateStatuses;

    /**
     * @var array
     */
    private $statuses;

    /**
     * @var Status
     */
    protected $orderStatusFactory;

    /**
     * @var \Magento\Sales\Model\ResourceModel\Order\Status\CollectionFactory
     */
    protected $orderStatusCollectionFactory;


    /**
     * Constructor
     *
     * @param \Magento\Sales\Model\Order\StatusFactory $orderStatusFactory
     * @param \Magento\Sales\Model\ResourceModel\Order\Status\CollectionFactory $orderStatusCollectionFactory
     * @param \Magento\Framework\App\State $state
     */
    public function __construct(        
        \Magento\Sales\Model\ResourceModel\Order\Status\CollectionFactory $orderStatusCollectionFactory,
        \Magento\Backend\Block\Template\Context $context, 
        array $data = []
    ) {
        $this->orderStatusCollectionFactory = $orderStatusCollectionFactory;
        parent::__construct($context, $data);
    }

    /**
     * Enable the "Add after" button or not
     *
     * @var bool
     */
    protected $_addAfter = true;

    /**
     * Rows cache
     *
     * @var array|null
     */
    private $_arrayRowsCache;

    /**
     * Prepare to render
     *
     * @return void
     */
    protected function _prepareToRender()
    {
               
        $eventTypeBlock=$this->getLayout()->createBlock('Magento\Framework\View\Element\Html\Select')
                        ->setId($this->_getCellInputElementId('<%- _id %>','event_type'))
                        ->setName($this->_getCellInputElementName('event_type'))
                        ->setClass('select')
                        ->setOptions(
                            array(
                                ['value' => '', 'label' => __('-- Please Select --')],
                                ['value' => 'order_place', 'label' => __('Place Order')],
                                ['value' => 'invoice_register', 'label' => __('Invoice Register')],
                                ['value' => 'order_status', 'label' => __('Order Status Update')]
                            )
                        );
        
        $this->addColumn('event_type', array(
            'label' => __('Event Type'),
            'renderer' => $eventTypeBlock
        ));
        $statuses = $this->orderStatusCollectionFactory->create()->toOptionHash();            
        array_unshift($statuses,  array('value' => '*', 'label' => __('-- Any --')));            

        $fromstatusesBlock=$this->getLayout()->createBlock('Magento\Framework\View\Element\Html\Select')
                        ->setId($this->_getCellInputElementId('<%- _id %>','from_status'))
                        ->setName($this->_getCellInputElementName('from_status'))
                        ->setClass('select')
                        ->setOptions($statuses);

        $this->addColumn('from_status', array(
            'label' => __('From Status'),
            'renderer' => $fromstatusesBlock
        ));

        $tostatusesBlock=$this->getLayout()->createBlock('Magento\Framework\View\Element\Html\Select')
                        ->setId($this->_getCellInputElementId('<%- _id %>','to_status'))
                        ->setName($this->_getCellInputElementName('to_status'))
                        ->setClass('select')
                        ->setOptions($statuses);

        $this->addColumn('to_status', array(
            'label' => __('To Status'),
            'renderer' => $tostatusesBlock
        ));


        $this->addColumn('event_endpoint', array(
            'label' => __('Event Endpoint')
            
        ));

        $this->_addAfter = false;
        $this->_addButtonLabel = __('Add new event');
    }

}
